About Weblate
=============

Project goals
-------------

Web-based continuous localization tool with tight :ref:`vcs` supporting a wide range of
:ref:`formats`, making it easy for translators to contribute.

Project name
------------

"Weblate" is a portmanteau of the words "web" and "translate".

Project website
---------------

The landing page is https://weblate.org and there is a
cloud-hosted service at https://hosted.weblate.org.
The documentation can be read at https://docs.weblate.org.

Project logos
-------------

The project logos and other graphics are available in
https://github.com/WeblateOrg/graphics.

Leadership
----------

This project is maintained by Michal Čihař, who can be reached at michal@cihar.com.

Authors
-------

Weblate was started by Michal Čihař. Since its inception in
2012, thousands of people have contributed.
